# Security Policy

## Supported Versions

Currently supported

| Version | Supported           |
|---------|---------------------|
|  0.0.0  |  :white_check_mark: |


## Reporting Security Issues

If you believe you have found a security vulnerability in a supported version of memoprop according to the table above, please do *not* create an Issue.
Instead, please contact `opensource@richlew.is` directly, detailing the problem.
We will endeavour to respond to these issues within 48 hours.
